@@ -1,4 +1,4 @@
-#include <catch2/catch.hpp>
+#include <catch2/catch_test_macros.hpp>
 #include <panda/backtrace.h>
 #include <panda/exception.h>
 #include "fn.h"
